@@ -149,8 +149,10 @@ additive <-
       args = args,
       eng_args = NULL,
       mode = mode,
+      user_specified_mode = !missing(mode),
       method = NULL,
-      engine = engine
+      engine = engine,
+      user_specified_engine = !missing(engine)
     )
   }
 
@@ -354,25 +356,6 @@ additive_fit <- function(formula, data, ...) {
   }
   dots$formula.override <- NULL
 
-  # Simplify and expose the family call
-  if (inherits(dots$family, c("family", "brmsfamily"))) {
-    family_chr <- purrr::map_lgl(dots$family, is.character)
-    family_func <- ifelse(
-      inherits(dots$family, "brmsfamily"),
-      "brmsfamily",
-      dots$family$family
-    )
-    family_fmls <- rlang::fn_fmls_names(
-      get(
-        family_func,
-        mode = "function"
-      )
-    )
-    family_chrs <- intersect(names(family_chr[family_chr]), family_fmls)
-    family_args <- dots$family[family_chrs]
-    dots$family <- rlang::call2(family_func, !!!family_args)
-  }
-
   # Check the fit function
   fitfunc <- as.list(dots$fitfunc)
   dots$fitfunc <- NULL
