@@ -390,7 +390,7 @@ additive_make <- function(modes = c("classification", "regression")) {
                 object$lvl[1]
               )
             } else if (
-              length(object$lvl) > 2 &
+              length(object$lvl) > 2 &&
                 length(object$lvl) == ncol(results)
             ) {
               if (length(threshold) == ncol(results)) {
@@ -429,10 +429,11 @@ additive_make <- function(modes = c("classification", "regression")) {
               )
               colnames(results) <- object$lvl
             } else if (
-              length(object$lvl) > 2 &
+              length(object$lvl) > 2 &&
                 length(object$lvl) == ncol(results)
             ) {
               colnames(results) <- object$lvl
+              results <- tibble::as_tibble(results)
             } else {
               rlang::abort("Unexpected model predictions!")
             }
@@ -458,22 +459,45 @@ additive_make <- function(modes = c("classification", "regression")) {
             hf_lvl <- (1 - object$spec$method$pred$conf_int$extras$level) / 2
             const <-
               stats::qt(hf_lvl, df = object$fit$df.residual, lower.tail = FALSE)
-            res_2 <-
-              tibble::tibble(
-                lo = results$fit - const * results$se.fit,
-                hi = results$fit + const * results$se.fit
-              )
-            res_1 <- res_2
-            res_1$lo <- 1 - res_2$hi
-            res_1$hi <- 1 - res_2$lo
             lo_nms <- paste0(".pred_lower_", object$lvl)
             hi_nms <- paste0(".pred_upper_", object$lvl)
-            colnames(res_1) <- c(lo_nms[1], hi_nms[1])
-            colnames(res_2) <- c(lo_nms[2], hi_nms[2])
-            res <- dplyr::bind_cols(res_1, res_2)
+            se_nms <- paste0(".std_error_", object$lvl)
+            if (length(object$lvl) == 2) {
+              res_2 <-
+                tibble::tibble(
+                  lo = results$fit - const * results$se.fit,
+                  hi = results$fit + const * results$se.fit
+                )
+              res_1 <- res_2
+              res_1$lo <- 1 - res_2$hi
+              res_1$hi <- 1 - res_2$lo
+              colnames(res_1) <- c(lo_nms[1], hi_nms[1])
+              colnames(res_2) <- c(lo_nms[2], hi_nms[2])
+              res <- dplyr::bind_cols(res_1, res_2)
 
-            if (object$spec$method$pred$conf_int$extras$std_error) {
-              res$.std_error <- results$se.fit
+              if (object$spec$method$pred$conf_int$extras$std_error) {
+                res$.std_error <- results$se.fit
+              }
+            } else if (
+              length(object$lvl) > 2 &&
+                length(object$lvl) == ncol(results$fit)
+            ) {
+              lo <- results$fit - const * results$se.fit
+              colnames(lo) <- lo_nms
+              lo <- tibble::as_tibble(lo)
+              hi <- results$fit + const * results$se.fit
+              colnames(hi) <- hi_nms
+              hi <- tibble::as_tibble(hi)
+              if (object$spec$method$pred$conf_int$extras$std_error) {
+                se <- results$se.fit
+                colnames(se) <- se_nms
+                se <- tibble::as_tibble(se)
+              } else {
+                se <- tibble()
+              }
+              res <- dplyr::bind_cols(lo, hi, se)
+            } else {
+              rlang::abort("Unexpected model predictions!")
             }
             res
           },
@@ -482,6 +506,8 @@ additive_make <- function(modes = c("classification", "regression")) {
             object = rlang::expr(object$fit),
             newdata = rlang::expr(new_data),
             type = "response",
+            interval = "confidence",
+            level = rlang::expr(level),
             se.fit = TRUE
           )
         )
@@ -498,22 +524,45 @@ additive_make <- function(modes = c("classification", "regression")) {
             hf_lvl <- (1 - object$spec$method$pred$pred_int$extras$level) / 2
             const <-
               stats::qt(hf_lvl, df = object$fit$df.residual, lower.tail = FALSE)
-            res_2 <-
-              tibble::tibble(
-                lo = results$fit - const * results$se.fit,
-                hi = results$fit + const * results$se.fit
-              )
-            res_1 <- res_2
-            res_1$lo <- 1 - res_2$hi
-            res_1$hi <- 1 - res_2$lo
             lo_nms <- paste0(".pred_lower_", object$lvl)
             hi_nms <- paste0(".pred_upper_", object$lvl)
-            colnames(res_1) <- c(lo_nms[1], hi_nms[1])
-            colnames(res_2) <- c(lo_nms[2], hi_nms[2])
-            res <- dplyr::bind_cols(res_1, res_2)
+            se_nms <- paste0(".std_error_", object$lvl)
+            if (length(object$lvl) == 2) {
+              res_2 <-
+                tibble::tibble(
+                  lo = results$fit - const * results$se.fit,
+                  hi = results$fit + const * results$se.fit
+                )
+              res_1 <- res_2
+              res_1$lo <- 1 - res_2$hi
+              res_1$hi <- 1 - res_2$lo
+              colnames(res_1) <- c(lo_nms[1], hi_nms[1])
+              colnames(res_2) <- c(lo_nms[2], hi_nms[2])
+              res <- dplyr::bind_cols(res_1, res_2)
 
-            if (object$spec$method$pred$pred_int$extras$std_error) {
-              res$.std_error <- results$se.fit
+              if (object$spec$method$pred$pred_int$extras$std_error) {
+                res$.std_error <- results$se.fit
+              }
+            } else if (
+              length(object$lvl) > 2 &&
+                length(object$lvl) == ncol(results$fit)
+            ) {
+              lo <- results$fit - const * results$se.fit
+              colnames(lo) <- lo_nms
+              lo <- tibble::as_tibble(lo)
+              hi <- results$fit + const * results$se.fit
+              colnames(hi) <- hi_nms
+              hi <- tibble::as_tibble(hi)
+              if (object$spec$method$pred$pred_int$extras$std_error) {
+                se <- results$se.fit
+                colnames(se) <- se_nms
+                se <- tibble::as_tibble(se)
+              } else {
+                se <- tibble()
+              }
+              res <- dplyr::bind_cols(lo, hi, se)
+            } else {
+              rlang::abort("Unexpected model predictions!")
             }
             res
           },
@@ -522,6 +571,8 @@ additive_make <- function(modes = c("classification", "regression")) {
             object = rlang::expr(object$fit),
             newdata = rlang::expr(new_data),
             type = "response",
+            interval = "prediction",
+            level = rlang::expr(level),
             se.fit = TRUE
           )
         )
@@ -579,6 +630,8 @@ additive_make <- function(modes = c("classification", "regression")) {
             object = rlang::expr(object$fit),
             newdata = rlang::expr(new_data),
             type = "response",
+            interval = "confidence",
+            level = rlang::expr(level),
             se.fit = TRUE
           )
         )
@@ -617,6 +670,8 @@ additive_make <- function(modes = c("classification", "regression")) {
             object = rlang::expr(object$fit),
             newdata = rlang::expr(new_data),
             type = "response",
+            interval = "prediction",
+            level = rlang::expr(level),
             se.fit = TRUE
           )
         )
